@@ -1,4 +1,5 @@
 import json
+import sys
 from logging import Logger
 from pathlib import Path
 from typing import List
@@ -31,31 +32,31 @@ def command_build(log: Logger, path: Path, commit: str, job: str = None, launch:
         repo = NumerousRepository(path).load()
     except Exception:
         print(red(f'Cannot build: {bold(path)} does not exist.'))
-        return
+        sys.exit(1)
 
     if repo.commit is None and commit is None:
         print(red("Cannot build: No commit checked out or specified."))
-        return
+        sys.exit(1)
 
     if repo.remote is None:
         print(red('Cannot build: No remote is configured for the repository.'))
         print(f"Use the command {bold('numerous config --remote <REMOTE_URL>')} to configure a remote for the "
               "repository.")
-        return
+        sys.exit(1)
 
     if repo.scenario is None:
         print(red('Cannot build: A scenario must be checked out.'))
-        return
+        sys.exit(1)
 
     if repo.snapshot is None or repo.commit is None:
         print(red("Cannot build: No push has been made to the remote."))
-        return
+        sys.exit(1)
 
     try:
         access_token = login(repo)
     except AuthenticationError:
         print(red("Cannot build: Login failed."))
-        return
+        sys.exit(1)
     call_credentials = grpc.metadata_call_credentials(TokenAuth(access_token))
 
     with get_build_manager(repo.remote.api_url) as build_manager:
@@ -80,7 +81,7 @@ def command_build(log: Logger, path: Path, commit: str, job: str = None, launch:
                         break
                 except BuildError:
                     print(red("Build failed: An error occured during the build."))
-                    return
+                    sys.exit(1)
 
         build_info_request = BuildInfoRequest(repository=repo.remote.name, build_id=build_id)
         build_info_response, _call = build_manager.GetBuildInfo.with_call(
