@@ -1,3 +1,4 @@
+import sys
 from logging import Logger
 from pathlib import Path
 
@@ -15,7 +16,7 @@ def command_init(log: Logger, path: Path):
         except Exception:
             print(red('Cannot init: Folder already exists, but repository configuration is invalid'))
         finally:
-            return
+            sys.exit(1)
 
     path.mkdir(parents=True, exist_ok=True)
 
