@@ -1,3 +1,4 @@
+import sys
 from logging import Logger
 from pathlib import Path
 
@@ -14,18 +15,18 @@ def command_login(log: Logger, path: Path, admin: bool):
     except Exception as excp:
         log.debug(f"Exception {type(excp)} {excp}")
         print(red(f"Cannot login: {bold(str(path))} is not a repository."))
-        return
+        sys.exit(1)
 
     if repo.remote is None:
         print(red('Cannot login: No remote is configured for the repository.'))
         print(f"Use the command {bold('numerous config --remote <REMOTE_URL>')} to configure a remote for the "
               "repository.")
-        return
+        sys.exit(1)
 
     if repo.scenario is None:
         print(red("Cannot re-login: A scenario must be checked out."))
         print(f"Check out a scenario with {bold('numerous checkout <SCENARIO ID>')}")
-        return
+        sys.exit(1)
 
     repo.token = None
     try:
@@ -33,4 +34,4 @@ def command_login(log: Logger, path: Path, admin: bool):
         print(green("Login succeeded."))
     except AuthenticationError:
         print(red("Login failed."))
-        return
+        sys.exit(1)
