@@ -19,26 +19,31 @@ log = logging.getLogger('numerous.build-cli')
 init_colorama()
 
 
-def red(msg: str) -> str:
+def red(msg: Any) -> str:
     return f"{Fore.RED}{msg}{Fore.RESET}"
 
 
-def green(msg: str) -> str:
+def green(msg: Any) -> str:
     return f"{Fore.GREEN}{msg}{Fore.RESET}"
 
 
-def cyan(msg: str) -> str:
+def cyan(msg: Any) -> str:
     return f"{Fore.CYAN}{msg}{Fore.RESET}"
 
 
-def yellow(msg: str) -> str:
+def yellow(msg: Any) -> str:
     return f"{Fore.YELLOW}{msg}{Fore.RESET}"
 
 
-def bold(msg) -> str:
+def bold(msg: Any) -> str:
     return f"{Style.BRIGHT}{msg}{Style.NORMAL}"
 
 
+def print_error_and_exit(msg: Any, exit_code: int = 1):
+    print(red(msg))
+    sys.exit(exit_code)
+
+
 def print_repository_help_message(path: Path):
     print(f" ! {bold('Remember to change directory to the repository:')} {bold(cyan(f'cd {path}'))}")
     print(f" * Connect a remote: {bold(cyan('numerous config --remote <REMOTE URL>'))}")
